pub struct ContainerHandle { /* private fields */ }Expand description
Container handle for local clients
Implementations
Sourceimpl ContainerHandle
impl ContainerHandle
Sourcepub fn new(client: Docker, store: StateStore) -> Self
pub fn new(client: Docker, store: StateStore) -> Self
Create a new container handle
Sourcepub async fn list_ids(
&self,
containers_status: Vec<ContainerStateStatusEnum>,
) -> Result<Vec<(Uuid, Option<String>)>>
pub async fn list_ids( &self, containers_status: Vec<ContainerStateStatusEnum>, ) -> Result<Vec<(Uuid, Option<String>)>>
List the container ids.
If the container status list is empty, all the ids are returned. This includes the ones of container that have not been created yet. Which will have a container_id unset.
Sourcepub async fn list(
&self,
containers_status: Vec<ContainerStateStatusEnum>,
) -> Result<HashMap<Uuid, ContainerSummary>>
pub async fn list( &self, containers_status: Vec<ContainerStateStatusEnum>, ) -> Result<HashMap<Uuid, ContainerSummary>>
List the container
Sourcepub async fn get_all(
&self,
containers_status: Vec<ContainerStateStatusEnum>,
) -> Result<Vec<(Uuid, ContainerInspectResponse)>>
pub async fn get_all( &self, containers_status: Vec<ContainerStateStatusEnum>, ) -> Result<Vec<(Uuid, ContainerInspectResponse)>>
Get all the containers
This will list the containers and get all the information
Sourcepub async fn get(&self, id: Uuid) -> Result<Option<ContainerInspectResponse>>
pub async fn get(&self, id: Uuid) -> Result<Option<ContainerInspectResponse>>
Get the container